/*
 * Ben NanoNote and EM027AS012 E-Paper Display Adapter Board communication.
 *
 * Copyright (C) 2013 Paul Boddie
 *
 * SPI functions derived from those in lib/atben.c by Werner Almesberger:
 *
 * Copyright (C) 2010-2011 Werner Almesberger
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __BSP_H__
#define __BSP_H__

#include <ubb/ubb.h>

/* Pin assignments:
 *
 * Sniffer  UBB   EM027AS012
 * -------  ----  -----------
 * DAT2     DAT2   4 (MOSI)
 * CD       DAT3   6 (SSEL)
 * CMD      CMD   11 (PWM)
 * VCC      VDD   13 (PANEL)
 * CLK      CLK    3 (SCK)
 * GND      GND
 * DAT0     DAT0  12 (RESET)
 * DAT1     DAT1  14 (DIS)
 *
 * Remember that the pin numbering is "mirrored" on the end of a cable:
 *
 *       Socket                   __
 * --------------------  ---------  ---------
 *  2  4  6  8 10 12 14   1  3  5  7  9 11 13
 *  1  3  5  7  9 11 13   2  4  6  8 10 12 14
 * ---------__---------  --------------------
 *                              Cable
 *
 * General connections:
 *
 * 3.3V Supply    EM027AS012
 * -----------    ----------
 * GND             1 (GND)
 * 3V3             2 (3V3)
 */

#define EPD_MOSI  UBB_DAT2
#define EPD_SSEL  UBB_DAT3
#define EPD_PWM   UBB_CMD
#define EPD_SCK   UBB_CLK
#define EPD_RESET UBB_DAT0
#define EPD_DIS   UBB_DAT1

/* Board-specific interface functions. */

void bsp_init();
void bsp_spiInit();
void bsp_writeToDisplay(uint8_t *data, uint16_t len);
void bsp_delayMs(uint32_t ms);
void bsp_delayUs(uint32_t us);
uint32_t bsp_getMsTicks();
int16_t bsp_getTemp();

#endif /* __BSP_H__ */
